ConcentricClipper class

Inheritance

Constructors

ConcentricClipper({double progress = 0.0, double verticalPosition = 0.85, double radius = 30.0, double growFactor = 30.0, bool reverse = false})
const

Properties

growFactor → double
final
hashCode → int
The hash code for this object.
no setterinherited
limit → double
final
progress → double
final
radius → double
final
reverse → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
verticalPosition → double
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be notified when it is time to reclip.
inherited
getApproximateClipRect(Size size) → Rect
Returns an approximation of the clip returned by getClip, as an axis-aligned Rect. This is used by the semantics layer to determine whether widgets should be excluded.
inherited
getClip(Size size) → Path
Returns a description of the clip given that the render object being clipped is of the given size.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies when it is time to reclip.
inherited
shouldReclip(covariant ConcentricClipper oldClipper) → bool
Called whenever a new instance of the custom clipper delegate class is provided to the clip object, or any time that a new clip object is created with a new instance of the custom clipper delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited