ConcentricPageView class

Inheritance

Constructors

ConcentricPageView({Key? key, required dynamic itemBuilder(int index), required List<Color> colors, Key? pageViewKey, dynamic onChange(int page)?, Function? onFinish, int? itemCount, PageController? pageController, bool pageSnapping = true, bool reverse = false, ValueNotifier? notifier, double scaleFactor = 0.3, double opacityFactor = 0.0, double radius = 40.0, double verticalPosition = 0.75, Axis direction = Axis.horizontal, ScrollPhysics? physics = const ClampingScrollPhysics(), Duration duration = const Duration(milliseconds: 1500), Curve curve = Curves.easeInOutSine, WidgetBuilder? nextButtonBuilder})
const

Properties

colors → List<Color>
final
curve → Curve
final
direction → Axis
final
duration → Duration
final
hashCode → int
The hash code for this object.
no setterinherited
itemBuilder → dynamic Function(int index)
final
itemCount → int?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
nextButtonBuilder → WidgetBuilder?
Useful for adding a next icon to the page view button
final
notifier → ValueNotifier?
final
onChange → dynamic Function(int page)?
final
onFinish → Function?
final
opacityFactor → double
final
pageController → PageController?
final
pageSnapping → bool
final
pageViewKey → Key?
final
physics → ScrollPhysics?
final
radius → double
final
reverse → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaleFactor → double
final
verticalPosition → double
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _ConcentricPageViewState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited